@@ -101,11 +101,10 @@ vardcros <- function(Y, H, PSU, w_final,
                      ischaracter = TRUE, namesID1 = names(ID_level1))
 
 
-    if(!is.null(X) | !is.null(ind_gr) | !is.null(g) | !is.null(q) | !is.null(countryX) | 
-       !is.null(periodX) | !is.null(X_ID_level1) | !is.null(datasetX)) {
+    if(!is.null(X)) {
         X <- check_var(vars = X, varn = "X", dataset = datasetX,
                        check.names = TRUE, isnumeric = TRUE,
-                       grepls = "__", dX = "X",
+                       grepls = "__",
                        dif_name = c(names(period), names(country), names(H),
                                     names(PSU), names(ID_level1), names(Y),
                                     "w_final", "w_design", "g", "q"))
@@ -114,37 +113,37 @@ vardcros <- function(Y, H, PSU, w_final,
 
         ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
                             dataset = datasetX, ncols = 1,
-                            Xnrow = Xnrow, ischaracter = TRUE, dX = "X",
+                            Xnrow = Xnrow, ischaracter = TRUE,
                             dif_name = c(names(period), names(country), names(H),
                                          names(PSU), names(ID_level1), names(Y),
                                          names(X), "w_final", "w_design", "g", "q"))
 
         g <- check_var(vars = g, varn = "g", dataset = datasetX,
                        ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
-                       isvector = TRUE, dX = "X")
+                       isvector = TRUE)
 
         q <- check_var(vars = q, varn = "q", dataset = datasetX,
                      ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
-                     isvector = TRUE, dX = "X")
+                     isvector = TRUE)
 
         countryX <- check_var(vars = countryX, varn = "countryX",
                               dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                               ischaracter = TRUE, mustbedefined = !is.null(country),
                               varnout = "country", varname = names(country),
-                              country = country, dX = "X")
+                              country = country)
                               
         periodX <- check_var(vars = periodX, varn = "periodX",
                              dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                              ischaracter = TRUE, mustbedefined = !is.null(period),
                              duplicatednames = TRUE, varnout = "period",
                              varname = names(period), country = country,
-                             countryX = countryX, periods = period, dX = "X")
+                             countryX = countryX, periods = period)
 
         X_ID_level1 <- check_var(vars = X_ID_level1, varn = "X_ID_level1",
                                  dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                                  ischaracter = TRUE, varnout = "ID_level1",
                                  varname = names(ID_level1), country = country,
-                                 countryX = countryX, periods = period, dX = "X",
+                                 countryX = countryX, periods = period,
                                  periodsX = periodX, ID_level1 = ID_level1)
       }
    }
@@ -314,11 +313,11 @@ vardcros <- function(Y, H, PSU, w_final,
     stderr_nw <- nhcor <- num1 <- num <- den1 <- den <- num_den1 <- NULL
     grad1 <- grad2 <- estim <- sd_nw <- stderr_w <- sd_w <- se <- rse <- NULL
     cv <- CI_lower <- absolute_margin_of_error <- CI_upper <- totalZ <- NULL
-    relative_margin_of_error <- confidence_level <- NULL
+    relative_margin_of_error <- NULL
 
 
     # Calibration
-    betas <- res_outp <- NULL
+    res_outp <- NULL
     if (!is.null(X)) {
          X0 <- data.table(X_ID_level1, ind_gr, q, g, X)
          if (!is.null(countryX)) X0 <- data.table(countryX, X0)
@@ -329,19 +328,14 @@ vardcros <- function(Y, H, PSU, w_final,
          ind_gr <- DT1[, c(namesperc, names(ind_gr)), with = FALSE]
          ind_period <- do.call("paste", c(as.list(ind_gr), sep = "_"))
 
-         res <- lapply(split(DT1[, .I], ind_period), function(i) {
-                         resid <- residual_est(Y = DT1[i, namesY2, with = FALSE],
-                                               X = DT1[i, names(X), with = FALSE],
-                                               weight = DT1[i][["w_design"]],
-                                               q = DT1[i][["q"]], dataset = NULL,
-                                               checking = FALSE)
-                         pers0 <- DT1[i, .N, keyby = c( nos[2:length(nos) - 1])]
-                         
-                         list(data.table(DT1[i, nos, with = FALSE], resid$residuals),
-                              data.table(pers0[, N := NULL], resid$betas))
-                                   })
-         betas <- rbindlist(lapply(res, function(x) x[[2]]))
-         res <- rbindlist(lapply(res, function(x) x[[1]]))
+         res <- lapply(split(DT1[, .I], ind_period), function(i)
+                        data.table(DT1[i, nos, with = FALSE],
+                                   res <- residual_est(Y = DT1[i, namesY2, with = FALSE],
+                                                       X = DT1[i, names(X), with = FALSE],
+                                                       weight = DT1[i][["w_design"]],
+                                                       q = DT1[i][["q"]], dataset = NULL,
+                                                       checking = FALSE)))
+         res <- rbindlist(res)
          setnames(res, namesY2, namesY2w)
          DTc <- merge(DTc, res, by = nos)
          if (outp_res) res_outp <- DTc[, c(nos, names_PSU, "w_final", namesY2w), with = FALSE]
@@ -426,9 +420,14 @@ vardcros <- function(Y, H, PSU, w_final,
  # STANDARD ERROR ESTIMATION 						      |
  #--------------------------------------------------------------------------*
 
-  DT1[, (names_H) := as.factor(get(names_H))]
-  DT1[, paste0(names_H, "_", levels(get(names_H)))] -> DT1H
-  DT1[, (DT1H) := transpose(lapply(get(names_H), FUN = function(x){as.numeric(x == levels(get(names_H)))})) ]
+
+  DT1H <- DT1[[names_H]]
+  DT1H <- factor(DT1H)
+  if (length(levels(DT1H)) == 1) { DT1[, stratasf := 1]
+                                 DT1H <- "stratasf"
+                       }  else { DT1H <- data.table(model.matrix( ~ DT1H - 1, DT1H,  contrasts = "contr.SAS"))
+                                 DT1 <- cbind(DT1, DT1H)
+                                 DT1H <- names(DT1H) }
 
   fits <-lapply(1 : length(namesY1), function(i) {
            fitss <- lapply(split(DT1, DT1$period_country), function(DT1c) {
@@ -437,7 +436,7 @@ vardcros <- function(Y, H, PSU, w_final,
                         if ((!is.null(namesZ1))&(!linratio)) z <- paste0(",", toString(namesZ1[i])) else z <- ""
 
                         funkc <- as.formula(paste("cbind(", trimws(toString(y)), z, ")~ 0 + ",
-                                       paste(c(0, DT1H), collapse= "+")))
+                                       paste(c(0, DT1H), collapse = "+")))
 
                         res1 <- lm(funkc, data = DT1c)
                         if (use.estVar == TRUE) {res1 <- data.table(crossprod(res1$res))
@@ -645,12 +644,7 @@ vardcros <- function(Y, H, PSU, w_final,
       if (!is.null(DTnet)) DTnet[, percoun := NULL]
       res1[, percoun := NULL]
       res[, percoun := NULL]  }
-
-  res[, confidence_level := confidence]
-  list(data_net_changes = DTnet,
-       res_out = res_outp,
-       var_grad = res1,
-       results = res)
+  list(data_net_changes = DTnet, res_out = res_outp, var_grad = res1, results = res)
 
 }
 
